# Read cvs list
$dir = "C:\Users\daniel\Documents\Protel\WiringPlan\ISC\D1900511\Project Outputs for D1900511"
$cables = Import-Csv -Path $dir\D1900511_CableList.csv 
# Exluded cables (already long enough)
$excl = "ISC_SQ_85", "ISC_SQ_86", "ISC_SQ_89", "ISC_SQ_106", "ISC_SQ_202_2", "ISC_SQ_207_2", "ISC_SQ_217_2", "ISC_SQ_222_2", "ISC_SQ_225_2", 
        "ISC_SQ_283", "ISC_SQ_311", "ISC_SQ_321", "ISC_SQ_322", "ISC_SQ_325", "ISC_SQ_384_1", "ISC_SQ_385_1", "ISC_SQ_386_1"
# Cable types
$coax="N","TNC","BNC","SMA"
$dsub="D9M","D9F","D15M","D15F","D25M","D25F","D37M","D37F","M12F","M12M"
$hv="SHV"
# Find duplicates
echo "Duplicates"
$cables | Sort -Property "Cable Label" |? "Cable Info" -eq "" |
    Group-Object -Property "Cable Label" -NoElement |? Count -gt 1
# Create list
$cables |
    ? System -eq "ISC_SQ" | 
    Sort -Property @{Expression={[Float]$_."Cable Number"}; Descending=$False} |
    ? {(($_."From Rack" -notmatch "SQZT") -and ($_."To Rack" -match "SQZT[07]-")) -or 
       (($_."To Rack" -notmatch "SQZT") -and ($_."From Rack" -match "SQZT[07]-")) -or
       ((427.0 -le $_."Cable Number") -and ("SQZT0","SQZT7"-notcontains $_."From Rack") -and ("SQZT0","SQZT7"-notcontains $_."To Rack")) } |
    ? {$excl -notcontains $_."Cable Label"} |
    Export-Csv -Encoding utf8 -NoTypeInformation -Path $dir\D1900511_CableList_SQZT.csv 
# Create coax list
$cables |
    ? System -eq "ISC_SQ" | 
    Sort -Property @{Expression={[Float]$_."Cable Number"}; Descending=$False} |
    ? {(($_."From Rack" -notmatch "SQZT") -and ($_."To Rack" -match "SQZT[07]-")) -or 
       (($_."To Rack" -notmatch "SQZT") -and ($_."From Rack" -match "SQZT[07]-")) -or
       ((427.0 -le $_."Cable Number") -and ("SQZT0","SQZT7"-notcontains $_."From Rack") -and ("SQZT0","SQZT7"-notcontains $_."To Rack")) } |
    ? {$excl -notcontains $_."Cable Label"} |
    ? {$coax -contains $_."From Connector Type"} |
    Export-Csv -Encoding utf8 -NoTypeInformation -Path $dir\D1900511_CableList_SQZT_Coax.csv 
# Create d-sub list
$cables |
    ? System -eq "ISC_SQ" | 
    Sort -Property @{Expression={[Float]$_."Cable Number"}; Descending=$False} |
    ? {(($_."From Rack" -notmatch "SQZT") -and ($_."To Rack" -match "SQZT[07]-")) -or 
       (($_."To Rack" -notmatch "SQZT") -and ($_."From Rack" -match "SQZT[07]-")) -or
       ((427.0 -le $_."Cable Number") -and ("SQZT0","SQZT7"-notcontains $_."From Rack") -and ("SQZT0","SQZT7"-notcontains $_."To Rack")) } |
    ? {$excl -notcontains $_."Cable Label"} |
    ? {$dsub -contains $_."From Connector Type"} |
    Export-Csv -Encoding utf8 -NoTypeInformation -Path $dir\D1900511_CableList_SQZT_Dsub.csv 
# Create SHV list
$cables |
    ? System -eq "ISC_SQ" | 
    Sort -Property @{Expression={[Float]$_."Cable Number"}; Descending=$False} |
    ? {(($_."From Rack" -notmatch "SQZT") -and ($_."To Rack" -match "SQZT[07]-")) -or 
       (($_."To Rack" -notmatch "SQZT") -and ($_."From Rack" -match "SQZT[07]-")) -or
       ((427.0 -le $_."Cable Number") -and ("SQZT0","SQZT7"-notcontains $_."From Rack") -and ("SQZT0","SQZT7"-notcontains $_."To Rack")) } |
    ? {$excl -notcontains $_."Cable Label"} |
    ? {$hv -contains $_."From Connector Type"} |
    Export-Csv -Encoding utf8 -NoTypeInformation -Path $dir\D1900511_CableList_SQZT_HV.csv 
# Check missed entries
echo ""
echo "Missing"
$cables |
    ? System -eq "ISC_SQ" | 
    Sort -Property @{Expression={[Float]$_."Cable Number"}; Descending=$False} |
    ? {(($_."From Rack" -notmatch "SQZT") -and ($_."To Rack" -match "SQZT[07]-")) -or 
       (($_."To Rack" -notmatch "SQZT") -and ($_."From Rack" -match "SQZT[07]-")) -or
       ((427.0 -le $_."Cable Number") -and ("SQZT0","SQZT7"-notcontains $_."From Rack") -and ("SQZT0","SQZT7"-notcontains $_."To Rack")) } |
    ? {$excl -notcontains $_."Cable Label"} |
    ? {$coax + $dsub + $hv -notcontains $_."From Connector Type"} |
    Group-Object -Property "Cable Label" -NoElement
